package
Version:
v0.0.0-...-949c8fb
Opens a new window with list of versions in this module.
Published: Feb 27, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CommandLoaderDeps struct {
fx.In
Cli *CLI
Commands []Command `group:"command"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.